##################################
Teledyne Oscilloscope base classes
##################################

Teledyne Oscilloscope
#####################

.. autoclass:: pymeasure.instruments.teledyne.TeledyneOscilloscope
   :members:
   :show-inheritance:

Teledyne Channel
################

.. autoclass:: pymeasure.instruments.teledyne.teledyne_oscilloscope.TeledyneOscilloscopeChannel
   :members:
   :show-inheritance:

Teledyne MAUI Oscilloscope
##########################

.. autoclass:: pymeasure.instruments.teledyne.TeledyneMAUI
   :members:
   :show-inheritance:

Teledyne MAUI Channel
#####################

.. autoclass:: pymeasure.instruments.teledyne.teledyneMAUI.TeledyneMAUIChannel
   :members:
   :show-inheritance:
